==> open-xchange-pop3_7.4.0.orig.tar.bz2: open-xchange-pop3-7.4.0/com.openexchange.pop3/src/com/openexchange/pop3/osgi/SessiondServiceServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.pop3.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.pop3.services.POP3ServiceRegistry;
import com.openexchange.sessiond.SessiondService;

/**
 * {@link SessiondServiceServiceTrackerCustomizer} - Service tracker customizer for {@link SessiondService}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class SessiondServiceServiceTrackerCustomizer implements ServiceTrackerCustomizer {

    private static final org.apache.commons.logging.Log LOG =
        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SessiondServiceServiceTrackerCustomizer.class));

    private final BundleContext context;

    /**
     * Initializes a new {@link SessiondServiceServiceTrackerCustomizer}.
     */
    public SessiondServiceServiceTrackerCustomizer(final BundleContext context) {
        super();
        this.context = context;
    }

    @Override
    public Object addingService(final ServiceReference reference) {
        final Object addedService = context.getService(reference);
        if (null == addedService) {
            LOG.warn("Added service is null!", new Throwable());
        }
        if ((addedService instanceof SessiondService)) {
            POP3ServiceRegistry.getServiceRegistry().addService(SessiondService.class, addedService);
            return addedService;
        }
        // Service needs not to be tracked
        context.ungetService(reference);
        return null;
    }

    @Override
    public void modifiedService(final ServiceReference reference, final Object service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference reference, final Object service) {
        if (null != service) {
            try {
                POP3ServiceRegistry.getServiceRegistry().removeService(SessiondService.class);
            } finally {
                context.ungetService(reference);
            }
        }
    }

}

==> open-xchange-pop3_7.4.1.orig.tar.bz2: open-xchange-pop3-7.4.1/com.openexchange.pop3/src/com/openexchange/pop3/osgi/SessiondServiceServiceTrackerCustomizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.pop3.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.pop3.services.POP3ServiceRegistry;
import com.openexchange.sessiond.SessiondService;

/**
 * {@link SessiondServiceServiceTrackerCustomizer} - Service tracker customizer for {@link SessiondService}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class SessiondServiceServiceTrackerCustomizer implements ServiceTrackerCustomizer<SessiondService,SessiondService> {

    private static final org.apache.commons.logging.Log LOG =
        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SessiondServiceServiceTrackerCustomizer.class));

    private final BundleContext context;

    /**
     * Initializes a new {@link SessiondServiceServiceTrackerCustomizer}.
     */
    public SessiondServiceServiceTrackerCustomizer(final BundleContext context) {
        super();
        this.context = context;
    }

    @Override
    public SessiondService addingService(final ServiceReference<SessiondService> reference) {
        final SessiondService addedService = context.getService(reference);
        if (null == addedService) {
            LOG.warn("Added service is null!", new Throwable());
        }
        POP3ServiceRegistry.getServiceRegistry().addService(SessiondService.class, addedService);
        return addedService;
    }

    @Override
    public void modifiedService(final ServiceReference<SessiondService> reference, final SessiondService service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference<SessiondService> reference, final SessiondService service) {
        if (null != service) {
            try {
                POP3ServiceRegistry.getServiceRegistry().removeService(SessiondService.class);
            } finally {
                context.ungetService(reference);
            }
        }
    }

}
